@@ -284,6 +284,11 @@ cmd_init(int argc, char *argv[])
 	char *repo_path = NULL;
 	int ch;
 
+#ifndef PROFILE
+	if (pledge("stdio rpath wpath cpath unveil", NULL) == -1)
+		err(1, "pledge");
+#endif
+
 	while ((ch = getopt(argc, argv, "b:")) != -1) {
 		switch (ch) {
 		case 'b':
@@ -298,10 +303,6 @@ cmd_init(int argc, char *argv[])
 	argc -= optind;
 	argv += optind;
 
-#ifndef PROFILE
-	if (pledge("stdio rpath wpath cpath unveil", NULL) == -1)
-		err(1, "pledge");
-#endif
 	if (argc != 1)
 		usage_init();
 
@@ -338,6 +339,12 @@ cmd_info(int argc, char *argv[])
 	char scaled[FMT_SCALED_STRSIZE];
 	int *pack_fds = NULL;
 
+#ifndef PROFILE
+	if (pledge("stdio rpath wpath cpath flock proc exec sendfd unveil",
+	    NULL) == -1)
+		err(1, "pledge");
+#endif
+
 	while ((ch = getopt(argc, argv, "r:")) != -1) {
 		switch (ch) {
 		case 'r':
@@ -356,11 +363,6 @@ cmd_info(int argc, char *argv[])
 	argc -= optind;
 	argv += optind;
 
-#ifndef PROFILE
-	if (pledge("stdio rpath wpath cpath flock proc exec sendfd unveil",
-	    NULL) == -1)
-		err(1, "pledge");
-#endif
 	if (repo_path == NULL) {
 		error = get_repo_path(&repo_path);
 		if (error)
@@ -450,7 +452,7 @@ done:
 __dead static void
 usage_pack(void)
 {
-	fprintf(stderr, "usage: %s pack [-aq] [-r repository-path] "
+	fprintf(stderr, "usage: %s pack [-aDq] [-r repository-path] "
 	    "[-x reference] [reference ...]\n", getprogname());
 	exit(1);
 }
@@ -690,7 +692,7 @@ cmd_pack(int argc, char *argv[])
 	const struct got_error *error = NULL;
 	char *repo_path = NULL;
 	struct got_repository *repo = NULL;
-	int ch, i, loose_obj_only = 1, verbosity = 0;
+	int ch, i, loose_obj_only = 1, force_refdelta = 0, verbosity = 0;
 	struct got_object_id *pack_hash = NULL;
 	char *id_str = NULL;
 	struct got_pack_progress_arg ppa;
@@ -706,11 +708,20 @@ cmd_pack(int argc, char *argv[])
 	TAILQ_INIT(&exclude_refs);
 	TAILQ_INIT(&include_refs);
 
-	while ((ch = getopt(argc, argv, "aqr:x:")) != -1) {
+#ifndef PROFILE
+	if (pledge("stdio rpath wpath cpath fattr flock proc exec sendfd unveil",
+	    NULL) == -1)
+		err(1, "pledge");
+#endif
+
+	while ((ch = getopt(argc, argv, "aDqr:x:")) != -1) {
 		switch (ch) {
 		case 'a':
 			loose_obj_only = 0;
 			break;
+		case 'D':
+			force_refdelta = 1;
+			break;
 		case 'q':
 			verbosity = -1;
 			break;
@@ -737,11 +748,6 @@ cmd_pack(int argc, char *argv[])
 	argc -= optind;
 	argv += optind;
 
-#ifndef PROFILE
-	if (pledge("stdio rpath wpath cpath fattr flock proc exec sendfd unveil",
-	    NULL) == -1)
-		err(1, "pledge");
-#endif
 	if (repo_path == NULL) {
 		error = get_repo_path(&repo_path);
 		if (error)
@@ -799,7 +805,7 @@ cmd_pack(int argc, char *argv[])
 
 	error = got_repo_pack_objects(&packfile, &pack_hash,
 	    &include_refs, &exclude_refs, repo, loose_obj_only,
-	    pack_progress, &ppa, check_cancelled, NULL);
+	    force_refdelta, pack_progress, &ppa, check_cancelled, NULL);
 	if (error) {
 		if (ppa.printed_something)
 			printf("\n");
@@ -1035,6 +1041,12 @@ cmd_listpack(int argc, char *argv[])
 	int show_stats = 0, human_readable = 0;
 	int *pack_fds = NULL;
 
+#ifndef PROFILE
+	if (pledge("stdio rpath wpath cpath flock proc exec sendfd unveil",
+	    NULL) == -1)
+		err(1, "pledge");
+#endif
+
 	while ((ch = getopt(argc, argv, "hs")) != -1) {
 		switch (ch) {
 		case 'h':
@@ -1058,11 +1070,6 @@ cmd_listpack(int argc, char *argv[])
 	if (packfile_path == NULL)
 		return got_error_from_errno2("realpath", argv[0]);
 
-#ifndef PROFILE
-	if (pledge("stdio rpath wpath cpath flock proc exec sendfd unveil",
-	    NULL) == -1)
-		err(1, "pledge");
-#endif
 	error = got_repo_pack_fds_open(&pack_fds);
 	if (error != NULL)
 		goto done;
@@ -1218,10 +1225,14 @@ cmd_cleanup(int argc, char *argv[])
 	char scaled_before[FMT_SCALED_STRSIZE];
 	char scaled_after[FMT_SCALED_STRSIZE];
 	char scaled_diff[FMT_SCALED_STRSIZE];
-	char **extensions;
-	int nextensions, i;
 	int *pack_fds = NULL;
 
+#ifndef PROFILE
+	if (pledge("stdio rpath wpath cpath flock proc exec sendfd unveil",
+	    NULL) == -1)
+		err(1, "pledge");
+#endif
+
 	while ((ch = getopt(argc, argv, "anpqr:")) != -1) {
 		switch (ch) {
 		case 'a':
@@ -1252,11 +1263,6 @@ cmd_cleanup(int argc, char *argv[])
 	argc -= optind;
 	argv += optind;
 
-#ifndef PROFILE
-	if (pledge("stdio rpath wpath cpath flock proc exec sendfd unveil",
-	    NULL) == -1)
-		err(1, "pledge");
-#endif
 	if (repo_path == NULL) {
 		error = get_repo_path(&repo_path);
 		if (error)
@@ -1273,15 +1279,11 @@ cmd_cleanup(int argc, char *argv[])
 	if (error)
 		goto done;
 
-	got_repo_get_gitconfig_extensions(&extensions, &nextensions,
-	    repo);
-	for (i = 0; i < nextensions; i++) {
-		if (strcasecmp(extensions[i], "preciousObjects") == 0) {
-			error = got_error_msg(GOT_ERR_GIT_REPO_EXT,
-			    "the preciousObjects Git extension is enabled; "
-			    "this implies that objects must not be deleted");
-			goto done;
-		}
+	if (got_repo_has_extension(repo, "preciousObjects")) {
+		error = got_error_msg(GOT_ERR_GIT_REPO_EXT,
+		    "the preciousObjects Git extension is enabled; "
+		    "this implies that objects must not be deleted");
+		goto done;
 	}
 
 	if (remove_lonely_packidx) {
