@@ -42,6 +42,10 @@ const struct got_error *got_deflate_read(struct got_deflate_buf *, FILE *,
 const struct got_error *got_deflate_read_mmap(struct got_deflate_buf *,
     uint8_t *, size_t, size_t, size_t *, size_t *);
 void got_deflate_end(struct got_deflate_buf *);
+const struct got_error *got_deflate_to_fd(off_t *, FILE *, off_t, int,
+    struct got_deflate_checksum *);
+const struct got_error *got_deflate_to_fd_mmap(off_t *, uint8_t *,
+    size_t, size_t, int, struct got_deflate_checksum *);
 const struct got_error *got_deflate_to_file(off_t *, FILE *, off_t, FILE *,
     struct got_deflate_checksum *);
 const struct got_error *got_deflate_to_file_mmap(off_t *, uint8_t *,
