@@ -41,7 +41,7 @@
 #include "got_opentemp.h"
 #include "got_path.h"
 
-#include "got_lib_sha1.h"
+#include "got_lib_hash.h"
 #include "got_lib_delta.h"
 #include "got_lib_inflate.h"
 #include "got_lib_object.h"
@@ -87,13 +87,13 @@ got_object_qid_alloc_partial(struct got_object_qid **qid)
 const struct got_error *
 got_object_id_str(char **outbuf, struct got_object_id *id)
 {
-	static const size_t len = SHA1_DIGEST_STRING_LENGTH;
+	static const size_t len = GOT_OBJECT_ID_HEX_MAXLEN;
 
 	*outbuf = malloc(len);
 	if (*outbuf == NULL)
 		return got_error_from_errno("malloc");
 
-	if (got_sha1_digest_to_str(id->sha1, *outbuf, len) == NULL) {
+	if (got_object_id_hex(id, *outbuf, len) == NULL) {
 		free(*outbuf);
 		*outbuf = NULL;
 		return got_error(GOT_ERR_BAD_OBJ_ID_STR);
@@ -102,6 +102,12 @@ got_object_id_str(char **outbuf, struct got_object_id *id)
 	return NULL;
 }
 
+char *
+got_object_id_hex(struct got_object_id *id, char *buf, size_t len)
+{
+	return got_sha1_digest_to_str(id->sha1, buf, len);
+}
+
 void
 got_object_close(struct got_object *obj)
 {
@@ -336,11 +342,7 @@ got_object_read_raw(uint8_t **outbuf, off_t *size, size_t *hdrlen,
 
 	SHA1Final(sha1, &sha1_ctx);
 	if (memcmp(expected_id->sha1, sha1, SHA1_DIGEST_LENGTH) != 0) {
-		char buf[SHA1_DIGEST_STRING_LENGTH];
-		err = got_error_fmt(GOT_ERR_OBJ_CSUM,
-		    "checksum failure for object %s",
-		    got_sha1_digest_to_str(expected_id->sha1, buf,
-		    sizeof(buf)));
+		err = got_error_checksum(expected_id);
 		goto done;
 	}
 
@@ -383,7 +385,7 @@ got_object_commit_add_parent(struct got_commit_object *commit,
 	if (err)
 		return err;
 
-	if (!got_parse_sha1_digest(qid->id.sha1, id_str)) {
+	if (!got_parse_object_id(&qid->id, id_str, GOT_HASH_SHA1)) {
 		err = got_error(GOT_ERR_BAD_OBJ_DATA);
 		got_object_qid_free(qid);
 		return err;
@@ -616,6 +618,7 @@ got_object_parse_commit(struct got_commit_object **commit, char *buf,
     size_t len)
 {
 	const struct got_error *err = NULL;
+	enum got_hash_algorithm algo = GOT_HASH_SHA1;
 	char *s = buf;
 	size_t label_len;
 	ssize_t remain = (ssize_t)len;
@@ -635,7 +638,7 @@ got_object_parse_commit(struct got_commit_object **commit, char *buf,
 			goto done;
 		}
 		s += label_len;
-		if (!got_parse_sha1_digest((*commit)->tree_id->sha1, s)) {
+		if (!got_parse_object_id((*commit)->tree_id, s, algo)) {
 			err = got_error(GOT_ERR_BAD_OBJ_DATA);
 			goto done;
 		}
@@ -758,12 +761,8 @@ got_object_read_commit(struct got_commit_object **commit, int fd,
 		return err;
 
 	SHA1Final(id.sha1, &sha1_ctx);
-	if (memcmp(expected_id->sha1, id.sha1, SHA1_DIGEST_LENGTH) != 0) {
-		char buf[SHA1_DIGEST_STRING_LENGTH];
-		err = got_error_fmt(GOT_ERR_OBJ_CSUM,
-		    "checksum failure for object %s",
-		    got_sha1_digest_to_str(expected_id->sha1, buf,
-		    sizeof(buf)));
+	if (got_object_id_cmp(expected_id, &id) != 0) {
+		err = got_error_checksum(expected_id);
 		goto done;
 	}
 
@@ -931,12 +930,8 @@ got_object_read_tree(struct got_parsed_tree_entry **entries, size_t *nentries,
 		return err;
 
 	SHA1Final(id.sha1, &sha1_ctx);
-	if (memcmp(expected_id->sha1, id.sha1, SHA1_DIGEST_LENGTH) != 0) {
-		char buf[SHA1_DIGEST_STRING_LENGTH];
-		err = got_error_fmt(GOT_ERR_OBJ_CSUM,
-		    "checksum failure for object %s",
-		    got_sha1_digest_to_str(expected_id->sha1, buf,
-		    sizeof(buf)));
+	if (got_object_id_cmp(expected_id, &id) != 0) {
+		err = got_error_checksum(expected_id);
 		goto done;
 	}
 
@@ -978,6 +973,7 @@ const struct got_error *
 got_object_parse_tag(struct got_tag_object **tag, uint8_t *buf, size_t len)
 {
 	const struct got_error *err = NULL;
+	enum got_hash_algorithm algo = GOT_HASH_SHA1;
 	size_t remain = len;
 	char *s = buf;
 	size_t label_len;
@@ -997,7 +993,7 @@ got_object_parse_tag(struct got_tag_object **tag, uint8_t *buf, size_t len)
 			goto done;
 		}
 		s += label_len;
-		if (!got_parse_sha1_digest((*tag)->id.sha1, s)) {
+		if (!got_parse_object_id(&(*tag)->id, s, algo)) {
 			err = got_error(GOT_ERR_BAD_OBJ_DATA);
 			goto done;
 		}
@@ -1175,12 +1171,8 @@ got_object_read_tag(struct got_tag_object **tag, int fd,
 		return err;
 
 	SHA1Final(id.sha1, &sha1_ctx);
-	if (memcmp(expected_id->sha1, id.sha1, SHA1_DIGEST_LENGTH) != 0) {
-		char buf[SHA1_DIGEST_STRING_LENGTH];
-		err = got_error_fmt(GOT_ERR_OBJ_CSUM,
-		    "checksum failure for object %s",
-		    got_sha1_digest_to_str(expected_id->sha1, buf,
-		    sizeof(buf)));
+	if (got_object_id_cmp(expected_id, &id) != 0) {
+		err = got_error_checksum(expected_id);
 		goto done;
 	}
 
