@@ -55,7 +55,7 @@
 #include "got_lib_object_create.h"
 #include "got_lib_pack.h"
 #include "got_lib_privsep.h"
-#include "got_lib_sha1.h"
+#include "got_lib_hash.h"
 #include "got_lib_object_cache.h"
 #include "got_lib_repository.h"
 #include "got_lib_gotconfig.h"
@@ -69,6 +69,28 @@
 RB_PROTOTYPE(got_packidx_bloom_filter_tree, got_packidx_bloom_filter, entry,
     got_packidx_bloom_filter_cmp);
 
+static inline int
+is_boolean_val(const char *val)
+{
+	return (strcasecmp(val, "true") == 0 ||
+	    strcasecmp(val, "false") == 0 ||
+	    strcasecmp(val, "on") == 0 ||
+    	    strcasecmp(val, "off") == 0 ||
+	    strcasecmp(val, "yes") == 0 ||
+    	    strcasecmp(val, "no") == 0 ||
+	    strcasecmp(val, "1") == 0 ||
+	    strcasecmp(val, "0") == 0);
+}
+
+static inline int
+get_boolean_val(const char *val)
+{
+	return (strcasecmp(val, "true") == 0 ||
+	    strcasecmp(val, "on") == 0 ||
+	    strcasecmp(val, "yes") == 0 ||
+	    strcasecmp(val, "1") == 0);
+}
+
 const char *
 got_repo_get_path(struct got_repository *repo)
 {
@@ -117,12 +139,17 @@ got_repo_get_gitconfig_owner(struct got_repository *repo)
 	return repo->gitconfig_owner;
 }
 
-void
-got_repo_get_gitconfig_extensions(char ***extensions, int *nextensions,
-    struct got_repository *repo)
+int
+got_repo_has_extension(struct got_repository *repo, const char *ext)
 {
-	*extensions = repo->extensions;
-	*nextensions = repo->nextensions;
+	int i;
+
+	for (i = 0; i < repo->nextensions; ++i) {
+		if (!strcasecmp(ext, repo->extnames[i]))
+			return get_boolean_val(repo->extvals[i]);
+	}
+
+	return 0;
 }
 
 int
@@ -588,7 +615,8 @@ read_gitconfig(struct got_repository *repo, const char *global_gitconfig_path)
 		err = got_repo_read_gitconfig(&dummy_repo_version,
 		    &repo->global_gitconfig_author_name,
 		    &repo->global_gitconfig_author_email,
-		    NULL, NULL, NULL, NULL, NULL, global_gitconfig_path);
+		    NULL, NULL, NULL, NULL, NULL, NULL,
+		    global_gitconfig_path);
 		if (err)
 			return err;
 	}
@@ -602,8 +630,8 @@ read_gitconfig(struct got_repository *repo, const char *global_gitconfig_path)
 	    &repo->gitconfig_repository_format_version,
 	    &repo->gitconfig_author_name, &repo->gitconfig_author_email,
 	    &repo->gitconfig_remotes, &repo->ngitconfig_remotes,
-	    &repo->gitconfig_owner, &repo->extensions, &repo->nextensions,
-	    repo_gitconfig_path);
+	    &repo->gitconfig_owner, &repo->extnames, &repo->extvals,
+	    &repo->nextensions, repo_gitconfig_path);
 	if (err)
 		goto done;
 
@@ -756,8 +784,18 @@ got_repo_open(struct got_repository **repop, const char *path,
 		goto done;
 	}
 	for (i = 0; i < repo->nextensions; i++) {
-		char *ext = repo->extensions[i];
+		char *ext = repo->extnames[i];
+		char *val = repo->extvals[i];
 		int j, supported = 0;
+
+		if (!is_boolean_val(val)) {
+			err = got_error_path(ext, GOT_ERR_GIT_REPO_EXT);
+			goto done;
+		}
+
+		if (!get_boolean_val(val))
+			continue;
+
 		for (j = 0; j < nitems(repo_extensions); j++) {
 			if (strcmp(ext, repo_extensions[j]) == 0) {
 				supported = 1;
@@ -842,9 +880,12 @@ got_repo_close(struct got_repository *repo)
 	for (i = 0; i < repo->ngitconfig_remotes; i++)
 		got_repo_free_remote_repo_data(&repo->gitconfig_remotes[i]);
 	free(repo->gitconfig_remotes);
-	for (i = 0; i < repo->nextensions; i++)
-		free(repo->extensions[i]);
-	free(repo->extensions);
+	for (i = 0; i < repo->nextensions; i++) {
+		free(repo->extnames[i]);
+		free(repo->extvals[i]);
+	}
+	free(repo->extnames);
+	free(repo->extvals);
 
 	got_pathlist_free(&repo->packidx_paths, GOT_PATHLIST_FREE_PATH);
 	free(repo);
@@ -1692,6 +1733,7 @@ match_loose_object(struct got_object_id **unique_id, const char *path_objects,
 	}
 	while ((dent = readdir(dir)) != NULL) {
 		int cmp;
+		enum got_hash_algorithm algo = GOT_HASH_SHA1;
 
 		free(id_str);
 		id_str = NULL;
@@ -1705,7 +1747,7 @@ match_loose_object(struct got_object_id **unique_id, const char *path_objects,
 			goto done;
 		}
 
-		if (!got_parse_sha1_digest(id.sha1, id_str))
+		if (!got_parse_object_id(&id, id_str, algo))
 			continue;
 
 		/*
@@ -2108,8 +2150,26 @@ write_tree(struct got_object_id **new_tree_id, const char *path_dir,
 		    strcmp(de->d_name, "..") == 0)
 			continue;
 
+		err = got_path_dirent_type(&type, path_dir, de);
+		if (err)
+			goto done;
+
 		TAILQ_FOREACH(pe, ignores, entry) {
-			if (fnmatch(pe->path, de->d_name, 0) == 0) {
+			if (type == DT_DIR && pe->path_len > 0 &&
+			    pe->path[pe->path_len - 1] == '/') {
+				char stripped[PATH_MAX];
+
+				if (strlcpy(stripped, pe->path,
+				    sizeof(stripped)) >= sizeof(stripped)) {
+					err = got_error(GOT_ERR_NO_SPACE);
+					goto done;
+				}
+				got_path_strip_trailing_slashes(stripped);
+				if (fnmatch(stripped, de->d_name, 0) == 0) {
+					ignore = 1;
+					break;
+				}
+			} else if (fnmatch(pe->path, de->d_name, 0) == 0) {
 				ignore = 1;
 				break;
 			}
@@ -2117,10 +2177,6 @@ write_tree(struct got_object_id **new_tree_id, const char *path_dir,
 		if (ignore)
 			continue;
 
-		err = got_path_dirent_type(&type, path_dir, de);
-		if (err)
-			goto done;
-
 		if (type == DT_DIR) {
 			err = import_subdir(&new_te, de, path_dir,
 			    ignores, repo, progress_cb, progress_arg);
@@ -2231,6 +2287,7 @@ got_repo_get_loose_object_info(int *nobjects, off_t *ondisk_size,
 			char *id_str;
 			int fd;
 			struct stat sb;
+			enum got_hash_algorithm algo = GOT_HASH_SHA1;
 
 			if (strcmp(dent->d_name, ".") == 0 ||
 			    strcmp(dent->d_name, "..") == 0)
@@ -2241,7 +2298,7 @@ got_repo_get_loose_object_info(int *nobjects, off_t *ondisk_size,
 				goto done;
 			}
 
-			if (!got_parse_sha1_digest(id.sha1, id_str)) {
+			if (!got_parse_object_id(&id, id_str, algo)) {
 				free(id_str);
 				continue;
 			}
