@@ -41,7 +41,7 @@
 #include "got_fetch.h"
 #include "got_reference.h"
 
-#include "got_lib_sha1.h"
+#include "got_lib_hash.h"
 #include "got_lib_delta.h"
 #include "got_lib_object.h"
 #include "got_lib_object_parse.h"
@@ -204,7 +204,7 @@ send_their_ref(struct imsgbuf *ibuf, struct got_object_id *refid,
 		return got_error_from_errno("imsg_create SEND_REMOTE_REF");
 
 	/* Keep in sync with struct got_imsg_send_remote_ref definition! */
-	if (imsg_add(wbuf, refid->sha1, SHA1_DIGEST_LENGTH) == -1)
+	if (imsg_add(wbuf, refid, sizeof(*refid)) == -1)
 		return got_error_from_errno("imsg_add SEND_REMOTE_REF");
 	if (imsg_add(wbuf, &reflen, sizeof(reflen)) == -1)
 		return got_error_from_errno("imsg_add SEND_REMOTE_REF");
@@ -411,7 +411,7 @@ send_pack(int fd, struct got_pathlist_head *refs,
 			err = got_error_from_errno("malloc");
 			goto done;
 		}
-		if (!got_parse_sha1_digest(id->sha1, id_str)) {
+		if (!got_parse_object_id(id, id_str, GOT_HASH_SHA1)) {
 			err = got_error(GOT_ERR_BAD_OBJ_ID_STR);
 			goto done;
 		}
@@ -714,7 +714,7 @@ main(int argc, char **argv)
 			err = got_error_from_errno("malloc");
 			goto done;
 		}
-		memcpy(id->sha1, href.id, SHA1_DIGEST_LENGTH);
+		memcpy(id, &href.id, sizeof(*id));
 		if (href.delete)
 			err = got_pathlist_append(&delete_refs, refname, id);
 		else
